#include "die.hpp"

Die::Die(int x, int y) : 
	MonostablePushButton(x, y, "", 0, 0)
{
	// establish a state variable for the icon
	die_state = 0;
	state = &die_state;

	// set the roll sound pitch
	frequency = 300;

	// roll the die once
	GetNextRoll();
}


void Die::GetNextRoll()
{
	// roll the die again
	float random = value.NextValue();

	// convert to integer in the range (1..6)
	current_roll = (random * 6) + 1;

	// convert to ascii for the button legend
	sprintf(legend, "%d", current_roll);
}

void Die::MakeSound()
{
	// make a short sound
	EventsHandler->SoundOn(frequency, 5);

	// change the pitch for next time
	frequency += 100;
	if (frequency == 1000) frequency = 300;
}

void Die::Update()
{
	if (*state == 0) return;
	// compute the next value of the die
	GetNextRoll();

	// issue a brief "computer" sound
	MakeSound();

	// turn off mouse so the die doesn't
	// obscure it
	EventsHandler->HideMouseCursor();

	// show the new value of the die
	Display();

	// put mouse cursor back on top of die
	EventsHandler->ShowMouseCursor();
}
